@@ -128,8 +128,10 @@ abstract class BaseRabbitController extends \yii\console\Controller {
      */
     protected static function getQueueCount(string $name): int {
         $name = strtoupper($name);
-        if (($count = getenv($name . '_QUEUE_COUNT')) !== false) {
-            return $count;
+        $name = str_replace('-', '_', $name);
+        $count = getenv($name . '_QUEUE_COUNT');
+        if ($count !== false) {
+            return intval($count);
         }
         return static::DEFAULT_QUEUE_COUNT;
     }
@@ -142,8 +144,10 @@ abstract class BaseRabbitController extends \yii\console\Controller {
      */
     protected function queueCount(string $name): int {
         $name = strtoupper($name);
-        if (($count = getenv($name . '_QUEUE_COUNT')) !== false) {
-            return $count;
+        $name = str_replace('-', '_', $name);
+        $count = getenv($name . '_QUEUE_COUNT');
+        if ($count !== false) {
+            return intval($count);
         }
         return static::DEFAULT_QUEUE_COUNT;
     }
@@ -232,7 +236,11 @@ abstract class BaseRabbitController extends \yii\console\Controller {
                     $queue = $rabbit->loadExistingQueue($baseQueueName . $stringNum);
                     if ($queue === null) {
                         // create the queue if it doesn't exist
-                        $queue = $rabbit->declareQueue($baseQueueName . $stringNum, [Rabbit::QUEUE_FLAG_DURABLE], ['x-single-active-consumer' => true]);
+                        $queue = $rabbit->declareQueue(
+                            $baseQueueName . $stringNum,
+                            [Rabbit::QUEUE_FLAG_DURABLE],
+                            ['x-single-active-consumer' => $this->queueCount($entity) > 1]
+                        );
                         $this->write("Creating...");
                     }
 
@@ -398,7 +406,11 @@ abstract class BaseRabbitController extends \yii\console\Controller {
                     $queue = $rabbit->loadExistingQueue($baseQueueName . $stringNum);
                     if ($queue === null) {
                         // create the queue if it doesn't exist
-                        $queue = $rabbit->declareQueue($baseQueueName . $stringNum, [Rabbit::QUEUE_FLAG_DURABLE], ['x-single-active-consumer' => true]);
+                        $queue = $rabbit->declareQueue(
+                            $baseQueueName . $stringNum,
+                            [Rabbit::QUEUE_FLAG_DURABLE],
+                            ['x-single-active-consumer' => self::getQueueCount($entity) > 1]
+                        );
                         echo "Creating...";
                     }
 
